# Chromoy
Обёртка от selenium chrome driver'а для парсинга и автотестов.

# Install
`pip install Chromoy`

# Usage

```python
from chromoy import Chromoy

driver = Chromoy(
        driver_file_path="file_path to chrome driver",
        debug=True
    )

```

# Possibilities

 TODO: docs